@@ -1,4 +1,4 @@
-/* $OpenBSD: ssl_cert.c,v 1.49 2014/12/14 15:30:50 jsing Exp $ */
+/* $OpenBSD: ssl_cert.c,v 1.50 2015/04/06 04:09:59 guenther Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -411,13 +411,6 @@ ssl_sess_cert_free(SESS_CERT *sc)
 	free(sc);
 }
 
-int
-ssl_set_peer_cert_type(SESS_CERT *sc, int type)
-{
-	sc->peer_cert_type = type;
-	return (1);
-}
-
 int
 ssl_verify_cert_chain(SSL *s, STACK_OF(X509) *sk)
 {
