@@ -1,4 +1,4 @@
-/* $OpenBSD: t1_lib.c,v 1.82 2015/07/24 07:57:48 doug Exp $ */
+/* $OpenBSD: t1_lib.c,v 1.84 2015/09/01 13:38:27 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -659,11 +659,6 @@ ssl_add_clienthello_tlsext(SSL *s, unsigned char *p, unsigned char *limit)
 		}
 	}
 
-	/* don't add extensions for SSLv3 unless doing secure renegotiation */
-	if (s->client_version == SSL3_VERSION &&
-	    !s->s3->send_connection_binding)
-		return p;
-
 	ret += 2;
 
 	if (ret >= limit)
@@ -973,10 +968,6 @@ ssl_add_serverhello_tlsext(SSL *s, unsigned char *p, unsigned char *limit)
 	    alg_a & SSL_aECDSA) &&
 	    s->session->tlsext_ecpointformatlist != NULL;
 
-	/* don't add extensions for SSLv3, unless doing secure renegotiation */
-	if (s->version == SSL3_VERSION && !s->s3->send_connection_binding)
-		return p;
-
 	ret += 2;
 	if (ret >= limit)
 		return NULL; /* this really never occurs, but ... */
@@ -1829,18 +1820,6 @@ ri_check:
 	return 1;
 }
 
-int
-ssl_prepare_clienthello_tlsext(SSL *s)
-{
-	return 1;
-}
-
-int
-ssl_prepare_serverhello_tlsext(SSL *s)
-{
-	return 1;
-}
-
 int
 ssl_check_clienthello_tlsext_early(SSL *s)
 {
@@ -2060,7 +2039,7 @@ tls1_process_ticket(SSL *s, const unsigned char *session, int session_len,
 	 */
 	if (SSL_get_options(s) & SSL_OP_NO_TICKET)
 		return 0;
-	if (s->version <= SSL3_VERSION || !limit)
+	if (!limit)
 		return 0;
 
 	if (limit < session)
